import 'package:desktop_ui/desktop_ui.dart';
import 'package:example/components/nav_bar.dart';
import 'package:example/constants.dart';
import 'package:example/content_container.dart';
import 'package:flutter/material.dart';

class MulitDemo extends StatelessWidget {
  const MulitDemo({Key? key}) : super(key: key);

  void _onChangeValue(int val) {
    print('修改后的值为：$val');
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: NavBar(
        title: '乱七八糟测试',
        isHaveBack: true,
      ),
      body: ListView(
        children: [
          ContentContainer(
            title: '空状态 - Empty',
            child: Column(children: const [
              SizedBox(
                child: EasyEmpty(
                  description: '无数据',
                ),
              ),
            ]),
          ),
          ContentContainer(
            title: '评分 - Rate',
            child: Column(children: [
              EasyRate(
                onChange: _onChangeValue,
              ),
              EasyRate(
                count: 10,
                allowClear: true,
                onChange: _onChangeValue,
              ),
              EasyRate(
                count: 10,
                disable: true,
                defaultValue: 5,
                onChange: _onChangeValue,
              ),
            ]),
          ),
          const ContentContainer(
            title: '提示 - Alert',
            child: EasySpace(
              direction: EasyDirectionType.vertical,
              children: [
                EasyAlert(message: 'Messge Title'),
                EasyAlert(
                  showIcon: true,
                  message: 'Messge Title',
                  description: 'message description',
                ),
                EasyAlert(
                  showIcon: true,
                  message: 'Messge Title',
                  description: 'message description',
                  type: EasyThemeType.info,
                ),
                EasyAlert(
                  showIcon: true,
                  message: 'Messge Title',
                  description: 'message description',
                  type: EasyThemeType.success,
                ),
                EasyAlert(
                  showIcon: true,
                  message: 'Messge Title',
                  description: 'message description',
                  type: EasyThemeType.warn,
                ),
                EasyAlert(
                  showIcon: true,
                  message: 'Messge Title',
                  description: 'message description',
                  type: EasyThemeType.error,
                ),
                EasyAlert(
                  showIcon: true,
                  icon: EasyIconData.add,
                  message: 'Messge Title',
                  description: 'message description',
                  type: EasyThemeType.info,
                  closable: true,
                ),
              ],
            ),
          ),
          ContentContainer(
            title: '标签-Tag',
            child: Column(
              children: const [
                EasySpace(
                  children: [
                    EasyTag(text: '标签'),
                    EasyTag(
                      text: '标签',
                      type: EasyThemeType.primary,
                    ),
                    EasyTag(
                      text: '标签',
                      type: EasyThemeType.success,
                    ),
                    EasyTag(
                      text: '标签',
                      type: EasyThemeType.info,
                    ),
                    EasyTag(
                      text: '标签',
                      type: EasyThemeType.warn,
                    ),
                    EasyTag(
                      text: '标签',
                      ghost: true,
                      type: EasyThemeType.error,
                    ),
                    EasyTag(
                      text: '标签',
                      ghost: true,
                      color: Colors.amber,
                    ),
                  ],
                ),
                SizedBox(
                  height: 10,
                ),
                EasySpace(
                  children: [
                    EasyTag(
                      text: '标签',
                      closable: true,
                      type: EasyThemeType.primary,
                    ),
                    EasyTag(
                      text: '标签',
                      ghost: true,
                      closable: true,
                      closeIcon: EasyIconData.eyeClose,
                      type: EasyThemeType.primary,
                    ),
                    EasyTag(
                      text: '标签',
                      ghost: true,
                      icon: EasyIconData.adjust,
                      closable: true,
                      closeIcon: EasyIconData.eyeClose,
                      type: EasyThemeType.error,
                    ),
                    EasyTag(
                      text: '标签',
                      ghost: true,
                      icon: EasyIconData.arrowDown,
                      closable: true,
                      closeIcon: EasyIconData.eyeClose,
                      type: EasyThemeType.primary,
                    ),
                  ],
                ),
              ],
            ),
          ),
          ContentContainer(
            title: '头像-Avatar',
            child: Column(
              children: const [
                EasySpace(
                  children: [
                    EasyAvatar(
                      src: avatarUrl,
                      size: EasyAvatarSize.small,
                    ),
                    EasyAvatar(src: avatarUrl),
                    EasyAvatar(
                      src: avatarUrl,
                      size: EasyAvatarSize.middle,
                      shape: EasyAvatarShape.square,
                    ),
                    EasyAvatar(
                      src: avatarUrl,
                      size: EasyAvatarSize.larger,
                    ),
                    EasyAvatar(
                      src: base64Value,
                      customerSize: 50,
                    ),
                  ],
                ),
                SizedBox(height: 10),
                EasySpace(children: [
                  EasyAvatarGroup(
                    avatarList: [avatarUrl, avatarUrl, avatarUrl, avatarUrl, avatarUrl],
                    customerSize: 50,
                  ),
                ]),
                EasySpace(children: [
                  EasyAvatarGroup(
                    maxCount: 3,
                    avatarList: [avatarUrl, avatarUrl, avatarUrl, avatarUrl, avatarUrl],
                    customerSize: 50,
                  ),
                ]),
                EasySpace(children: [
                  EasyAvatarGroup(
                    maxCount: 3,
                    avatarList: [avatarUrl, avatarUrl, avatarUrl, avatarUrl, avatarUrl],
                  ),
                ]),
              ],
            ),
          ),
          ContentContainer(
            title: '弹窗',
            child: Column(
              children: [
                EasyButton(
                  text: '打开弹框',
                  onClick: () {
                    showModalBottomSheet(
                        context: context,
                        builder: (context) {
                          return Text('内容');
                        });
                  },
                )
              ],
            ),
          ),
        ],
      ),
    );
  }
}
