import 'package:desktop_ui/components/block.dart';
import 'package:desktop_ui/constants.dart';
import 'package:desktop_ui/desktop_ui.dart';
import 'package:desktop_ui/utils/alert.dart';
import 'package:desktop_ui/utils/common.dart';
import 'package:flutter/material.dart';

class EasyAlert extends StatelessWidget {
  const EasyAlert({
    Key? key,
    required this.message,
    this.description,
    this.type = EasyThemeType.primary,
    this.onClose,
    this.closable = false,
    this.showIcon = false,
    this.icon,
  }) : super(key: key);

  /// 提示内容
  final String message;

  /// 提示详细描述信息
  final String? description;

  /// 主题类型，取值：EasyThemeType
  final EasyThemeType? type;

  /// 关闭事件
  final VoidCallback? onClose;

  /// 是否显示关闭按钮
  final bool? closable;

  /// 是否展示前边图标
  final bool? showIcon;

  /// 自定义前部图标，showIcon 为 true 是生效
  final IconData? icon;

  Widget _buildMessage() {
    List<Widget> _list = <Widget>[];
    if (showIcon != null && showIcon!) {
      _list.add(Padding(
        padding: iGapRight,
        child: EasyIcon(
          icon ?? getAlertIcon(type),
          size: 18,
          color: getBackgroundColor(type: type),
        ),
      ));
    }
    _list.add(Expanded(child: Text(message, style: iTitleTextBoldStyle)));
    if (closable!) {
      _list.add(Padding(
        padding: iGapLeft,
        child: InkWell(
          onTap: () {
            if (onClose != null) onClose?.call();
          },
          child: const EasyIcon(
            EasyIconData.close,
            size: 16,
            color: iTitleColor,
          ),
        ),
      ));
    }
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      crossAxisAlignment: CrossAxisAlignment.center,
      children: _list,
    );
  }

  Widget _buildDesc() {
    return description != null
        ? Padding(
            padding: const EdgeInsets.only(left: 0, top: iDefaultGap),
            child: Text(description ?? '', style: iContentTextStyle),
          )
        : const EasyBlock();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: iGapAll,
      decoration: BoxDecoration(
        border: Border.all(color: getBackgroundColor(type: type), width: 1.0),
        color: getBackgroundColor(type: type).withAlpha(30),
        borderRadius: iBorderRadiusSmall,
      ),
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          _buildMessage(),
          _buildDesc(),
        ],
      ),
    );
  }
}
