import 'package:desktop_ui/constants.dart';
import 'package:desktop_ui/enums/avatar.dart';
import 'package:desktop_ui/utils/avatar.dart';
import 'package:desktop_ui/utils/common.dart';
import 'package:flutter/material.dart';

/// 头像 - Avatar
class EasyAvatar extends StatelessWidget {
  const EasyAvatar({
    Key? key,
    required this.src,
    this.size,
    this.shape,
    this.customerSize,
  }) : super(key: key);

  /// 头像地址，支持：本地图片、网络图片、base64图片
  final String src;

  /// 头像大小，取值：EasyAvatarSize
  final EasyAvatarSize? size;

  /// 头像形状，取值：EasyAvatarShape
  final EasyAvatarShape? shape;

  /// 自定义大小，优先级大于 size
  final double? customerSize;

  @override
  Widget build(BuildContext context) {
    double _avatarSize = customerSize ?? getAvatarSize(size);
    bool isSquare = shape != null && shape == EasyAvatarShape.square;
    return Container(
      width: _avatarSize,
      height: _avatarSize,
      clipBehavior: Clip.hardEdge,
      decoration: BoxDecoration(
        borderRadius: BorderRadius.all(Radius.circular(isSquare ? 2 : _avatarSize)),
        border: Border.all(color: iBorderColor, width: 0.5),
        color: iGrayLight,
        image: DecorationImage(
          image: dealImageInfo(src),
          fit: BoxFit.cover,
        ),
      ),
    );
  }
}

/// 头像组
class EasyAvatarGroup extends StatelessWidget {
  const EasyAvatarGroup({
    Key? key,
    required this.avatarList,
    this.maxCount,
    this.size,
    this.customerSize,
  }) : super(key: key);

  /// 头像列表
  final List<String> avatarList;

  /// 显示的最大头像数
  final int? maxCount;

  final EasyAvatarSize? size;

  /// 自定义大小，优先级大于 size
  final double? customerSize;

  Widget _buildMore(int num, double size) {
    return Container(
      width: size,
      height: size,
      clipBehavior: Clip.hardEdge,
      decoration: BoxDecoration(
        borderRadius: BorderRadius.all(Radius.circular(size)),
        border: Border.all(color: iWarn, width: 0.5),
        color: iWarn,
      ),
      child: Center(
        child: Text(
          '+$num',
          style: TextStyle(fontSize: size / 2.5, color: iWhite),
        ),
      ),
    );
  }

  List<Widget> _buildChildren() {
    double _avatarSize = customerSize ?? getAvatarSize(size);
    List<Widget> _list = <Widget>[];
    for (int i = 0; i < avatarList.length; i++) {
      String item = avatarList[i];

      if (i > 0) {
        _list.add(Positioned(
          top: 0,
          width: _avatarSize,
          height: _avatarSize,
          left: i * _avatarSize - i * (_avatarSize / 5),
          child: EasyAvatar(src: item, size: size, customerSize: customerSize),
        ));
      } else {
        _list.add(EasyAvatar(src: item, size: size, customerSize: customerSize));
      }
      if (maxCount != null && _list.length == maxCount!) {
        _list.add(Positioned(
          top: 0,
          width: _avatarSize,
          height: _avatarSize,
          left: (i + 1) * _avatarSize - (i + 1) * (_avatarSize / 5),
          child: _buildMore(avatarList.length - _list.length, _avatarSize),
        ));
        break;
      }
    }
    return _list;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: iGapAllSmall,
      child: Stack(
        alignment: AlignmentDirectional.centerStart,
        clipBehavior: Clip.none,
        children: _buildChildren(),
      ),
    );
  }
}
