import 'package:desktop_ui/constants.dart';
import 'package:desktop_ui/desktop_ui.dart';
import 'package:flutter/material.dart';

typedef ChangeCallback = void Function(int val);

class EasyRate extends StatefulWidget {
  const EasyRate({
    Key? key,
    this.count = 5,
    this.disable,
    this.defaultValue,
    this.onChange,
    this.icon,
    this.allowClear = false,
  }) : super(key: key);

  /// star 总数，默认：5
  final int count;

  /// 只读，无法交互
  final bool? disable;

  /// 是否允许再次点击清除
  final bool? allowClear;

  /// 默认值
  final int? defaultValue;

  /// 修改的值改变的回调
  final ChangeCallback? onChange;

  /// 自定义图标
  final IconData? icon;

  @override
  State<EasyRate> createState() => _EasyRateState();
}

class _EasyRateState extends State<EasyRate> {
  int _star = 0;

  @override
  initState() {
    super.initState();
    setState(() {
      _star = widget.defaultValue ?? 0;
    });
  }

  List<Widget> _buildStar() {
    List<Widget> _list = <Widget>[];
    for (int i = 0; i < widget.count; i++) {
      int _targetVal = i + 1;
      bool isActive = _star < _targetVal;
      _list.add(InkWell(
        onTap: () {
          if (widget.disable != null && widget.disable!) return;
          setState(() {
            if (_star == _targetVal && widget.allowClear!) {
              _star = 0;
            } else {
              _star = _targetVal;
            }
            if (widget.onChange != null) widget.onChange?.call(_star);
          });
        },
        child: EasyIcon(
          widget.icon ?? EasyIconData.favorite,
          color: isActive ? iGray : iStarActiveColor,
        ),
      ));
    }
    return _list;
  }

  @override
  Widget build(BuildContext context) {
    return Row(
      children: _buildStar(),
    );
  }
}
