import 'package:desktop_ui/constants.dart';
import 'package:desktop_ui/desktop_ui.dart';
import 'package:desktop_ui/utils/common.dart';
import 'package:flutter/material.dart';

class EasyTag extends StatelessWidget {
  const EasyTag({
    Key? key,
    required this.text,
    this.closable,
    this.type,
    this.icon,
    this.closeIcon,
    this.color,
    this.ghost,
    this.onClose,
  }) : super(key: key);

  final String text;

  /// 主题类型，取值：EasyThemeType，优先级大于color
  final EasyThemeType? type;

  /// 是否是镂空
  final bool? ghost;

  /// 是否存在关闭按钮
  final bool? closable;

  /// 自定义关闭图标
  final IconData? closeIcon;

  /// 关闭回调
  final VoidCallback? onClose;

  /// 自定义图标
  final IconData? icon;

  /// 自定义颜色
  final Color? color;

  List<Widget> _buildContent() {
    List<Widget> list = <Widget>[];
    bool isHaveIcon = icon != null;
    bool isHaveClose = closable != null && closable!;
    if (isHaveIcon) {
      list.add(
        Center(
          child: EasyIcon(
            icon,
            size: 12,
            color: getTextColor(type: type, ghost: ghost, color: color),
          ),
        ),
      );
    }
    list.add(
      Center(
        child: Text(
          text,
          style: TextStyle(
            fontSize: iFontSizeSmall,
            fontWeight: iFontWeight,
            color: getTextColor(type: type, ghost: ghost, color: color),
          ),
        ),
      ),
    );
    if (isHaveClose) {
      list.add(
        InkWell(
          onTap: () {
            if (onClose != null) onClose?.call();
          },
          child: Center(
            child: EasyIcon(
              closeIcon ?? EasyIconData.close,
              color: getTextColor(type: type, ghost: ghost, color: color),
              size: 12,
            ),
          ),
        ),
      );
    }
    return list;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      height: iTagHeight,
      padding: iGapHorizontalSmall,
      decoration: BoxDecoration(
        border: Border.all(color: getBorderColor(type: type, ghost: ghost, color: color)),
        color: getBackgroundColor(type: type, ghost: ghost, color: color),
        borderRadius: const BorderRadius.all(Radius.circular(2.0)),
      ),
      child: EasySpace(
        size: EasySpaceSize.small,
        children: _buildContent(),
      ),
    );
  }
}
