// 公共方法
import 'dart:convert';
import 'dart:io';
import 'dart:typed_data';
import 'package:desktop_ui/constants.dart';
import 'package:desktop_ui/enums/common.dart';
import 'package:desktop_ui/utils/reg.dart';
import 'package:flutter/material.dart';

/// 通过类型返回对应的颜色
Color getColorByThemeType(EasyThemeType? type, {Color? baseColor}) {
  if (type == null) return baseColor ?? iBlack;
  Color color;
  switch (type) {
    case EasyThemeType.primary:
      color = iPrimary;
      break;
    case EasyThemeType.success:
      color = iSuccess;
      break;
    case EasyThemeType.info:
      color = iInfo;
      break;
    case EasyThemeType.warn:
      color = iWarn;
      break;
    case EasyThemeType.error:
      color = iError;
      break;
  }
  return color;
}

/// 获取文本颜色
Color getTextColor({
  EasyThemeType? type,
  bool? ghost,
  Color? color,
}) {
  Color textColor = iBlack;
  bool isGhost = ghost != null && ghost;
  bool isSelfColor = color != null;
  if (type == null) return isSelfColor ? (isGhost ? color : iWhite) : textColor;
  switch (type) {
    case EasyThemeType.primary:
      textColor = isGhost ? iPrimary : iWhite;
      break;
    case EasyThemeType.info:
      textColor = isGhost ? iInfo : iWhite;
      break;
    case EasyThemeType.success:
      textColor = isGhost ? iSuccess : iWhite;
      break;
    case EasyThemeType.warn:
      textColor = isGhost ? iWarn : iWhite;
      break;
    case EasyThemeType.error:
      textColor = isGhost ? iError : iWhite;
      break;
    default:
      textColor = iBlack;
      break;
  }
  return textColor;
}

Color getBorderColor({
  EasyThemeType? type,
  bool? ghost,
  Color? color,
}) {
  Color borderColor = color ?? iBorderColor;
  if (type == null) return borderColor;
  switch (type) {
    case EasyThemeType.primary:
      borderColor = iPrimary;
      break;
    case EasyThemeType.info:
      borderColor = iInfo;
      break;
    case EasyThemeType.success:
      borderColor = iSuccess;
      break;
    case EasyThemeType.warn:
      borderColor = iWarn;
      break;
    case EasyThemeType.error:
      borderColor = iError;
      break;
  }
  return borderColor;
}

Color getBackgroundColor({
  EasyThemeType? type,
  bool? ghost,
  Color? color,
}) {
  bool isGhost = ghost != null && ghost;
  if (isGhost) return iTransparent;
  Color bgColor = color ?? iBorderColor;
  if (type == null) return bgColor;
  switch (type) {
    case EasyThemeType.primary:
      bgColor = iPrimary;
      break;
    case EasyThemeType.info:
      bgColor = iInfo;
      break;
    case EasyThemeType.success:
      bgColor = iSuccess;
      break;
    case EasyThemeType.warn:
      bgColor = iWarn;
      break;
    case EasyThemeType.error:
      bgColor = iError;
      break;
  }
  return bgColor;
}

Widget dealImageWidget(String src) {
  if (urlMatch.hasMatch(src)) {
    return Image.network(src, fit: BoxFit.cover);
  }
  if (fileMatch.hasMatch(src)) {
    return Image.file(File(src), fit: BoxFit.cover);
  }
  if (src.contains('base64')) {
    String val = src.split(',')[1];
    Uint8List bytes = const Base64Decoder().convert(val);
    return Image.memory(bytes, fit: BoxFit.cover);
  }
  return const Text('');
}

ImageProvider<Object> dealImageInfo(String src) {
  if (urlMatch.hasMatch(src)) {
    return NetworkImage(src);
  }
  if (fileMatch.hasMatch(src)) {
    return FileImage(File(src));
  }
  if (src.contains('base64')) {
    String val = src.split(',')[1];
    Uint8List bytes = const Base64Decoder().convert(val);
    return MemoryImage(bytes);
  }
  return const AssetImage('lib/assets/avatar.png');
}
